

========================================================
curves
========================================================


.. toctree::
    :maxdepth: 10

    ./ArcCurve_autogen.rst
    ./CatmullRomCurve3_autogen.rst
    ./CubicBezierCurve3_autogen.rst
    ./CubicBezierCurve_autogen.rst
    ./EllipseCurve_autogen.rst
    ./LineCurve3_autogen.rst
    ./LineCurve_autogen.rst
    ./QuadraticBezierCurve3_autogen.rst
    ./QuadraticBezierCurve_autogen.rst
    ./SplineCurve_autogen.rst
